.. _azure-plugin:

============
Azure Plugin
============

This plugin allows you to run tests on Microsoft Azure Virtual
Machine instances. `Details available here <https://github.com/yuxisun1217/avocado-azure>`__
